# wickedql

Wicked cool python tools for GraphQL

<a href='https://codecov.io/github/wickedql/wickedql/'><img src='https://codecov.io/github/wickedql/wickedql/branch/master/graph/badge.svg' align="right" /></a>
<a href='https://travis-ci.org/wickedql/wickedql'><img src='https://img.shields.io/travis/wickedql/wickedql.svg' align="right" /></a>
<a href='https://pypi.python.org/pypi/wickedql'><img src='https://img.shields.io/pypi/v/wickedql.svg' align="right" /></a>

## Usage

## Installation

```
pip install wickedql
```

## Setup development environment

If you want to work on this project, you need setup your development
environment using the following commands.

```
$ pip install pipenv
$ pipenv install --dev
$ pipenv shell
```

## License

"wickedql" is licensed under the MIT license. For more information see LICENSE.

## Changelog

### 0.0.1

 * Initial commit.

## Contributors

 * WickedQL
